@@ -1,5 +1,5 @@
 /* This file is part of KCachegrind.
-   Copyright (c) 2011-2015 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
+   Copyright (c) 2011-2016 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
    KCachegrind is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -40,257 +40,254 @@
 
 // for source lines
 SourceItem::SourceItem(SourceView* sv, QTreeWidget* parent,
-		       int fileno, unsigned int lineno,
+                       int fileno, unsigned int lineno,
                        bool inside, const QString& src,
                        TraceLine* line)
     : QTreeWidgetItem(parent)
 {
-  _view = sv;
-  _lineno = lineno;
-  _fileno = fileno;
-  _inside = inside;
-  _line = line;
-  _lineCall = 0;
-  _lineJump = 0;
+    _view = sv;
+    _lineno = lineno;
+    _fileno = fileno;
+    _inside = inside;
+    _line = line;
+    _lineCall = 0;
+    _lineJump = 0;
 
-  setTextAlignment(0, Qt::AlignRight);
-  setTextAlignment(1, Qt::AlignRight);
-  setTextAlignment(2, Qt::AlignRight);
+    setTextAlignment(0, Qt::AlignRight);
+    setTextAlignment(1, Qt::AlignRight);
+    setTextAlignment(2, Qt::AlignRight);
 
-  if (src == "...")
-      setText(0, src);
-  else
-      setText(0, QString::number(lineno));
+    if (src == QLatin1String("..."))
+        setText(0, src);
+    else
+        setText(0, QString::number(lineno));
 
-  QString s = src;
-  setText(4, s.replace( QRegExp("\t"), "        " ));
+    QString s = src;
+    setText(4, s.replace( QRegExp(QStringLiteral("\t")), QStringLiteral("        ") ));
 
-  // to allow text selection after double click
-  setFlags(flags() | Qt::ItemIsEditable);
+    // to allow text selection after double click
+    setFlags(flags() | Qt::ItemIsEditable);
 
-  updateGroup();
-  updateCost();
+    updateGroup();
+    updateCost();
 }
 
 // for call lines
 SourceItem::SourceItem(SourceView* sv, QTreeWidgetItem* parent,
-		       int fileno, unsigned int lineno,
+                       int fileno, unsigned int lineno,
                        TraceLine* line, TraceLineCall* lineCall)
     : QTreeWidgetItem(parent)
 {
-  _view = sv;
-  _lineno = lineno;
-  _fileno = fileno;
-  _inside = true;
-  _line = line;
-  _lineCall = lineCall;
-  _lineJump = 0;
+    _view = sv;
+    _lineno = lineno;
+    _fileno = fileno;
+    _inside = true;
+    _line = line;
+    _lineCall = lineCall;
+    _lineJump = 0;
 
-  setTextAlignment(0, Qt::AlignRight);
-  setTextAlignment(1, Qt::AlignRight);
-  setTextAlignment(2, Qt::AlignRight);
+    setTextAlignment(0, Qt::AlignRight);
+    setTextAlignment(1, Qt::AlignRight);
+    setTextAlignment(2, Qt::AlignRight);
 
-  //qDebug("SourceItem: (file %d, line %d) Linecall to %s",
-  //       fileno, lineno, _lineCall->call()->called()->prettyName().toAscii());
+    //qDebug("SourceItem: (file %d, line %d) Linecall to %s",
+    //       fileno, lineno, _lineCall->call()->called()->prettyName().toAscii());
 
-  SubCost cc = _lineCall->callCount();
-  QString callStr = "  ";
-  if (cc==0) {
-      if (((TraceItemView*)_view)->data()->maxCallCount() > 0)
-          callStr += QObject::tr("Active call to '%1'");
-      else
-          callStr += QObject::tr("Call to '%1'");
-      callStr = callStr.arg(_lineCall->call()->calledName());
-  }
-  else
-      callStr += QObject::tr("%n call(s) to '%2'", "", (uint64)cc)
-          .arg(_lineCall->call()->calledName());
+    SubCost cc = _lineCall->callCount();
+    QString callStr = QStringLiteral("  ");
+    if (cc==0) {
+        if (((TraceItemView*)_view)->data()->maxCallCount() > 0)
+            callStr += QObject::tr("Active call to '%1'");
+        else
+            callStr += QObject::tr("Call to '%1'");
+        callStr = callStr.arg(_lineCall->call()->calledName());
+    }
+    else
+        callStr += QObject::tr("%n call(s) to '%2'", "", (uint64)cc)
+                   .arg(_lineCall->call()->calledName());
 
-  TraceFunction* calledF = _lineCall->call()->called();
-  calledF->addPrettyLocation(callStr);
+    TraceFunction* calledF = _lineCall->call()->called();
+    calledF->addPrettyLocation(callStr);
 
-  setText(4, callStr);
+    setText(4, callStr);
 
-  updateGroup();
-  updateCost();
+    updateGroup();
+    updateCost();
 }
 
 // for jump lines
 SourceItem::SourceItem(SourceView* sv, QTreeWidgetItem* parent,
-		       int fileno, unsigned int lineno,
+                       int fileno, unsigned int lineno,
                        TraceLine* line, TraceLineJump* lineJump)
     : QTreeWidgetItem(parent)
 {
-  _view = sv;
-  _lineno = lineno;
-  _fileno = fileno;
-  _inside = true;
-  _line = line;
-  _lineCall = 0;
-  _lineJump = lineJump;
+    _view = sv;
+    _lineno = lineno;
+    _fileno = fileno;
+    _inside = true;
+    _line = line;
+    _lineCall = 0;
+    _lineJump = lineJump;
 
-  setTextAlignment(0, Qt::AlignRight);
-  setTextAlignment(1, Qt::AlignRight);
-  setTextAlignment(2, Qt::AlignRight);
+    setTextAlignment(0, Qt::AlignRight);
+    setTextAlignment(1, Qt::AlignRight);
+    setTextAlignment(2, Qt::AlignRight);
 
-  //qDebug("SourceItem: (file %d, line %d) Linecall to %s",
-  //       fileno, lineno, _lineCall->call()->called()->prettyName().toAscii());
+    //qDebug("SourceItem: (file %d, line %d) Linecall to %s",
+    //       fileno, lineno, _lineCall->call()->called()->prettyName().toAscii());
 
-  QString to;
-  if (_lineJump->lineTo()->functionSource() == _line->functionSource())
-      to = _lineJump->lineTo()->name();
-  else
-      to = _lineJump->lineTo()->prettyName();
+    QString to;
+    if (_lineJump->lineTo()->functionSource() == _line->functionSource())
+        to = _lineJump->lineTo()->name();
+    else
+        to = _lineJump->lineTo()->prettyName();
 
-  QString jStr;
-  if (_lineJump->isCondJump())
-      jStr = QObject::tr("Jump %1 of %2 times to %3")
-	  .arg(_lineJump->followedCount().pretty())
-	  .arg(_lineJump->executedCount().pretty())
-	  .arg(to);
-  else
-      jStr = QObject::tr("Jump %1 times to %2")
-	  .arg(_lineJump->executedCount().pretty())
-	  .arg(to);
+    QString jStr;
+    if (_lineJump->isCondJump())
+        jStr = QObject::tr("Jump %1 of %2 times to %3")
+               .arg(_lineJump->followedCount().pretty())
+               .arg(_lineJump->executedCount().pretty())
+               .arg(to);
+    else
+        jStr = QObject::tr("Jump %1 times to %2")
+               .arg(_lineJump->executedCount().pretty())
+               .arg(to);
 
-  setText(4, jStr);
+    setText(4, jStr);
 }
 
 
 void SourceItem::updateGroup()
 {
-  if (!_lineCall) return;
+    if (!_lineCall) return;
 
-  TraceFunction* f = _lineCall->call()->called();
-  QColor c = GlobalGUIConfig::functionColor(_view->groupType(), f);
-  setIcon(4, colorPixmap(10, 10, c));
+    TraceFunction* f = _lineCall->call()->called();
+    QColor c = GlobalGUIConfig::functionColor(_view->groupType(), f);
+    setIcon(4, colorPixmap(10, 10, c));
 }
 
 void SourceItem::updateCost()
 {
-  _pure = SubCost(0);
-  _pure2 = SubCost(0);
+    _pure = SubCost(0);
+    _pure2 = SubCost(0);
 
-  if (!_line) return;
-  if (_lineJump) return;
+    if (!_line) return;
+    if (_lineJump) return;
 
-  ProfileCostArray* lineCost = _lineCall ? (ProfileCostArray*)_lineCall : (ProfileCostArray*)_line;
+    ProfileCostArray* lineCost = _lineCall ? (ProfileCostArray*)_lineCall : (ProfileCostArray*)_line;
 
-  // do not show any cost inside of cycles
-  if (_lineCall &&
-      ((_lineCall->call()->inCycle()>0) ||
-       (_lineCall->call()->isRecursion()))) {
-    QString str;
-    QPixmap p;
+    // do not show any cost inside of cycles
+    if (_lineCall &&
+        ((_lineCall->call()->inCycle()>0) ||
+         (_lineCall->call()->isRecursion()))) {
+        QString str;
+        QPixmap p;
 
-    QString icon = "edit-undo";
-#if 0 // TODO
-    KIconLoader* loader = KIconLoader::global();
-    p= loader->loadIcon(icon, KIconLoader::Small, 0,
-                        KIconLoader::DefaultState, QStringList(), 0, true);
-#endif
-    if (p.isNull())
-      str = QObject::tr("(cycle)");
+        QFontMetrics fm(font(4));
+        p = QIcon::fromTheme(QStringLiteral("edit-undo")).pixmap(fm.height());
 
-    setText(1, str);
-    setIcon(1, p);
-    setText(2, str);
-    setIcon(2, p);
-    return;
-  }
+        if (p.isNull())
+            str = QObject::tr("(cycle)");
 
-  ProfileCostArray* totalCost;
-  if (GlobalConfig::showExpanded())
-    totalCost = _line->functionSource()->function()->inclusive();
-  else
-    totalCost = _line->functionSource()->function()->data();
+        setText(1, str);
+        setIcon(1, p);
+        setText(2, str);
+        setIcon(2, p);
+        return;
+    }
 
-  EventType* ct = _view->eventType();
-  _pure = ct ? lineCost->subCost(ct) : SubCost(0);
-  if (_pure == 0) {
-    setText(1, QString());
-    setIcon(1, QPixmap());
-  }
-  else {
-    double total = totalCost->subCost(ct);
-    double pure  = 100.0 * _pure / total;
-
-    if (GlobalConfig::showPercentage())
-      setText(1, QString("%1")
-	      .arg(pure, 0, 'f', GlobalConfig::percentPrecision()));
+    ProfileCostArray* totalCost;
+    if (GlobalConfig::showExpanded())
+        totalCost = _line->functionSource()->function()->inclusive();
     else
-      setText(1, _pure.pretty());
+        totalCost = _line->functionSource()->function()->data();
 
-    setIcon(1, costPixmap(ct, lineCost, total, false));
-  }
+    EventType* ct = _view->eventType();
+    _pure = ct ? lineCost->subCost(ct) : SubCost(0);
+    if (_pure == 0) {
+        setText(1, QString());
+        setIcon(1, QPixmap());
+    }
+    else {
+        double total = totalCost->subCost(ct);
+        double pure  = 100.0 * _pure / total;
 
-  EventType* ct2 = _view->eventType2();
-  _pure2 = ct2 ? lineCost->subCost(ct2) : SubCost(0);
-  if (_pure2 == 0) {
-    setText(2, QString());
-    setIcon(2, QPixmap());
-  }
-  else {
-    double total = totalCost->subCost(ct2);
-    double pure2  = 100.0 * _pure2 / total;
+        if (GlobalConfig::showPercentage())
+            setText(1, QStringLiteral("%1")
+                    .arg(pure, 0, 'f', GlobalConfig::percentPrecision()));
+        else
+            setText(1, _pure.pretty());
 
-    if (GlobalConfig::showPercentage())
-      setText(2, QString("%1")
-	      .arg(pure2, 0, 'f', GlobalConfig::percentPrecision()));
-    else
-      setText(2, _pure2.pretty());
+        setIcon(1, costPixmap(ct, lineCost, total, false));
+    }
 
-    setIcon(2, costPixmap(ct2, lineCost, total, false));
-  }
+    EventType* ct2 = _view->eventType2();
+    _pure2 = ct2 ? lineCost->subCost(ct2) : SubCost(0);
+    if (_pure2 == 0) {
+        setText(2, QString());
+        setIcon(2, QPixmap());
+    }
+    else {
+        double total = totalCost->subCost(ct2);
+        double pure2  = 100.0 * _pure2 / total;
+
+        if (GlobalConfig::showPercentage())
+            setText(2, QStringLiteral("%1")
+                    .arg(pure2, 0, 'f', GlobalConfig::percentPrecision()));
+        else
+            setText(2, _pure2.pretty());
+
+        setIcon(2, costPixmap(ct2, lineCost, total, false));
+    }
 }
 
 
 bool SourceItem::operator < ( const QTreeWidgetItem & other ) const
 {
-  const SourceItem* si1 = this;
-  const SourceItem* si2 = (SourceItem*) &other;
-  int col = treeWidget()->sortColumn();
+    const SourceItem* si1 = this;
+    const SourceItem* si2 = (SourceItem*) &other;
+    int col = treeWidget()->sortColumn();
 
-  if (col==1) {
-    return (si1->_pure < si2->_pure);
-  }
-  if (col==2) {
-    return (si1->_pure2 < si2->_pure2);
-  }
-  if (col==0) {
-    // Sort file numbers
-    if (si1->_fileno < si2->_fileno) return true;
-    if (si1->_fileno > si2->_fileno) return false;
-
-    // Sort line numbers
-    if (si1->_lineno < si2->_lineno) return true;
-    if (si1->_lineno > si2->_lineno) return false;
-
-    // Same line: code gets above calls/jumps
-    if (!si1->_lineCall && !si1->_lineJump) return true;
-    if (!si2->_lineCall && !si2->_lineJump) return false;
-
-    // calls above jumps
-    if (si1->_lineCall && !si2->_lineCall) return true;
-    if (si2->_lineCall && !si1->_lineCall) return false;
-
-    if (si1->_lineCall && si2->_lineCall) {
-	// Two calls: desending sort according costs
-        if (si1->_pure < si2->_pure) return true;
-        if (si1->_pure > si2->_pure) return false;
-
-	// Two calls: sort according function names
-	TraceFunction* f1 = si1->_lineCall->call()->called();
-	TraceFunction* f2 = si2->_lineCall->call()->called();
-        if (f1->prettyName() > f2->prettyName()) return false;
-        return true;
+    if (col==1) {
+        return (si1->_pure < si2->_pure);
     }
+    if (col==2) {
+        return (si1->_pure2 < si2->_pure2);
+    }
+    if (col==0) {
+        // Sort file numbers
+        if (si1->_fileno < si2->_fileno) return true;
+        if (si1->_fileno > si2->_fileno) return false;
 
-    // Two jumps: descending sort according target line
-    return (si1->_lineJump->lineTo()->lineno() <
-        si2->_lineJump->lineTo()->lineno());
-  }
-  return QTreeWidgetItem::operator <(other);
+        // Sort line numbers
+        if (si1->_lineno < si2->_lineno) return true;
+        if (si1->_lineno > si2->_lineno) return false;
+
+        // Same line: code gets above calls/jumps
+        if (!si1->_lineCall && !si1->_lineJump) return true;
+        if (!si2->_lineCall && !si2->_lineJump) return false;
+
+        // calls above jumps
+        if (si1->_lineCall && !si2->_lineCall) return true;
+        if (si2->_lineCall && !si1->_lineCall) return false;
+
+        if (si1->_lineCall && si2->_lineCall) {
+            // Two calls: desending sort according costs
+            if (si1->_pure < si2->_pure) return true;
+            if (si1->_pure > si2->_pure) return false;
+
+            // Two calls: sort according function names
+            TraceFunction* f1 = si1->_lineCall->call()->called();
+            TraceFunction* f2 = si2->_lineCall->call()->called();
+            if (f1->prettyName() > f2->prettyName()) return false;
+            return true;
+        }
+
+        // Two jumps: descending sort according target line
+        return (si1->_lineJump->lineTo()->lineno() <
+                si2->_lineJump->lineTo()->lineno());
+    }
+    return QTreeWidgetItem::operator <(other);
 }
 
 void SourceItem::setJumpArray(const QVector<TraceLineJump*>& a)
@@ -311,8 +308,8 @@ SourceItemDelegate::SourceItemDelegate(SourceView *parent)
 }
 
 QWidget* SourceItemDelegate::createEditor(QWidget *parent,
-					  const QStyleOptionViewItem &option,
-					  const QModelIndex &index) const
+                                          const QStyleOptionViewItem &option,
+                                          const QModelIndex &index) const
 {
     QWidget* w = QItemDelegate::createEditor(parent, option, index);
     QLineEdit* e = qobject_cast<QLineEdit*>(w);
@@ -332,24 +329,24 @@ QSize SourceItemDelegate::sizeHint(const QStyleOptionViewItem &option,
     int levels = sv->arrowLevels();
 
     if (levels == 0)
-      return QSize(0, sz.height());
+        return QSize(0, sz.height());
 
     // 10 pixels for the arrow, 1 pixel margin left and right
     return QSize(10 + 6*levels + 2, sz.height());
 }
 
 void SourceItemDelegate::paint(QPainter *painter,
-			       const QStyleOptionViewItem &option,
-			       const QModelIndex &index) const
+                               const QStyleOptionViewItem &option,
+                               const QModelIndex &index) const
 {
     int column = index.column();
     SourceItem* item = static_cast<SourceItem*>(index.internalPointer());
 
     QColor color;
     if ( !item->inside() || ((column==1) || (column==2)))
-      color = option.palette.color( QPalette::Button );
+        color = option.palette.color( QPalette::Button );
     else if ((item->lineCall() || item->lineJump()) && column>2)
-      color = option.palette.color( QPalette::Midlight );
+        color = option.palette.color( QPalette::Midlight );
     if (color.isValid())
         _parent->model()->setData(index, color, Qt::BackgroundRole);
 
@@ -360,8 +357,8 @@ void SourceItemDelegate::paint(QPainter *painter,
 }
 
 void SourceItemDelegate::paintArrows(QPainter *p,
-				     const QStyleOptionViewItem &option,
-				     const QModelIndex &index) const
+                                     const QStyleOptionViewItem &option,
+                                     const QModelIndex &index) const
 {
     QTreeWidget *lv = _parent;
     if ( !lv ) return;
